
## CATO-CLI - mutation.policy.internetFirewall.removeSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSection) for documentation on this operation.

### Usage for mutation.policy.internetFirewall.removeSection:

`catocli mutation policy internetFirewall removeSection -h`

`catocli mutation policy internetFirewall removeSection <json>`

`catocli mutation policy internetFirewall removeSection "$(cat < removeSection.json)"`

`catocli mutation policy internetFirewall removeSection '{"internetFirewallPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}, "policyRemoveSectionInput": {"id": {"id": "ID"}}}'`

#### Operation Arguments for mutation.policy.internetFirewall.removeSection ####
`accountId` [ID] - (required) N/A 
`internetFirewallPolicyMutationInput` [InternetFirewallPolicyMutationInput] - (optional) N/A 
`policyRemoveSectionInput` [PolicyRemoveSectionInput] - (required) N/A 
